Stan Math Library: Member List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::accumulator< T > Member List

This is the complete list of members for stan::math::accumulator< T >, including all inherited members.

accumulator() | stan::math::accumulator< T > | inline
add(S x) | stan::math::accumulator< T > | inline
add(const S &x) | stan::math::accumulator< T > | inline
add(const Eigen::Matrix< S, R, C > &m) | stan::math::accumulator< T > | inline
add(const std::vector< S > &xs) | stan::math::accumulator< T > | inline
sum() const | stan::math::accumulator< T > | inline
~accumulator() | stan::math::accumulator< T > | inline

[ Stan Home Page ] © 2011–2016, Stan Development Team.